from distutils.core import setup
setup(
  name = 'jkspy',
  packages = ['jkspy'], # this must be the same as the name above
  version = '0.1',
  description = 'Python utilities for doing computer stuff',
  author = 'Kumseok Jung',
  author_email = 'jungkumseok@gmail.com',
  url = 'https://github.com/jungkumseok/jkspy',
  download_url = 'https://github.com/jungkumseok/jks/tarball/0.1', # I'll explain this in a second
  keywords = ['testing', 'utility'], 
  classifiers = [],
)